@@ -1,5 +1,5 @@
 from abc import ABCMeta, abstractmethod
-from typing import Iterable
+from typing import Iterable, Optional
 
 __all__ = ('Actioner',)
 
@@ -7,7 +7,7 @@ __all__ = ('Actioner',)
 class Actioner(metaclass=ABCMeta):
 
     @abstractmethod
-    def probe(self, obj, context: dict) -> Iterable[str]:
+    def probe(self, obj, context: dict) -> Optional[Iterable[str]]:
         """Return an iterable of action names this actioner can perform given the object and
         the context"""
 
